Crate remy

Crate remy 

Porting defaults

Structs

PLATFORMS
Platform
A Platform details a Docker and cargo build target configuration for building Rust applications
PortConfig
PortConfig parameterizes a port job

Functions

executable_suffix
Supply the standard executable suffix for a given target environment
new_portconfig
Build a default PortConfig
port
Generate application ports based on a PortConfig and a collection of binary basenames